@@ -3,9 +3,9 @@ package Sah::Schemas::Str;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-22'; # DATE
+our $DATE = '2022-09-23'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 1;
 # ABSTRACT: Various string schemas
@@ -22,7 +22,7 @@ Sah::Schemas::Str - Various string schemas
 
 =head1 VERSION
 
-This document describes version 0.012 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2022-09-22.
+This document describes version 0.013 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2022-09-23.
 
 =head1 SAH SCHEMAS
 
@@ -32,7 +32,10 @@ The following schemas are included in this distribution:
 
 =item * L<hexstr|Sah::Schema::hexstr>
 
-String of bytes in hexadecimal.
+String of bytes in hexadecimal notation, e.g. "ab99" or "CAFE".
+
+Whitespace is allowed and will be removed.
+
 
 =item * L<latin_alpha|Sah::Schema::latin_alpha>
 
@@ -44,17 +47,47 @@ String containing only zero or more Latin lettersE<sol>digits, i.e. A-Za-z0-9.
 
 =item * L<latin_letter|Sah::Schema::latin_letter>
 
-Latin letter, i.e. A-Z or a-z.
+A single latin letter, i.e. A-Z or a-z.
+
+=item * L<latin_lowercase_alpha|Sah::Schema::latin_lowercase_alpha>
+
+String containing only zero or more lowercases Latin letters, i.e. a-z.
+
+Uppercase letters will be coerced to lowercase.
+
+
+=item * L<latin_lowercase_letter|Sah::Schema::latin_lowercase_letter>
+
+A single latin lowercase letter, i.e. a-z.
+
+=item * L<latin_uppercase_alpha|Sah::Schema::latin_uppercase_alpha>
+
+String containing only zero or more uppercase Latin letters, i.e. A-Z.
+
+Uppercase letters will be coerced to lowercase.
+
+
+=item * L<latin_uppercase_letter|Sah::Schema::latin_uppercase_letter>
+
+A single latin uppercase letter, i.e. A-Z.
+
+=item * L<non_empty_str|Sah::Schema::non_empty_str>
+
+A non-empty string (length E<gt>= 1) (alias for str1).
 
 =item * L<percent_str|Sah::Schema::percent_str>
 
-A number in percent form.
+A number in percent form, e.g. "10.5%".
 
 This schema accepts floating number followed by percent sign. Unlike the
 C<percent> schema from L<Sah::Schemas::Float>, The percent sign will not be
 removed nor the number be converted to decimal (e.g. 50% to 0.5).
 
 
+=item * L<str1|Sah::Schema::str1>
+
+A non-empty string (length E<gt>= 1).
+
 =item * L<str_or_aos|Sah::Schema::str_or_aos>
 
 String or array (0+ length) of (defined) string.
